@@ -999,6 +999,10 @@ func (t *tScreen) parseSgrMouse(buf *bytes.Buffer, evs *[]Event) (bool, bool) {
 	i := 0
 	val := 0
 
+	if t.escaped {
+		state = 1
+	}
+
 	for i = range b {
 		switch b[i] {
 		case '\x1b':
@@ -1033,6 +1037,7 @@ func (t *tScreen) parseSgrMouse(buf *bytes.Buffer, evs *[]Event) (bool, bool) {
 				return false, false
 			}
 			if dig || neg {
+
 				return false, false
 			}
 			neg = true // stay in state
@@ -1117,6 +1122,10 @@ func (t *tScreen) parseXtermMouse(buf *bytes.Buffer, evs *[]Event) (bool, bool)
 	x := 0
 	y := 0
 
+	if t.escaped {
+		state = 1
+	}
+
 	for i := range b {
 		switch state {
 		case 0:
@@ -1462,8 +1471,8 @@ func (t *tScreen) mainLoop() {
 }
 
 func (t *tScreen) inputLoop() {
-	chunk := make([]byte, 4096)
 	for {
+		chunk := make([]byte, 4096)
 		n, e := t.in.Read(chunk)
 		switch e {
 		case io.EOF:
